@@ -53,7 +53,7 @@ namespace Mistelix.Dialogs
 
 			Copyright = "Jordi Mas i Hern\u00e0ndez <jmas@softcatala.org>";
 			Comments = Catalog.GetString ("Mistelix is a DVD authoring application also with slideshow creation capabilities.");
-			Website = "http://www.mistelix.org";
+			Website = Defines.PROJECT_URL;
 			WebsiteLabel = Catalog.GetString ("Mistelix web site");
 			TranslatorCredits = translators;
 			Response += delegate (object o, Gtk.ResponseArgs e) {Destroy ();};
