@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2008-2009 Jordi Mas i Hernandez, jmas@softcatala.org
+// Copyright (C) 2008-2010 Jordi Mas i Hernandez, jmas@softcatala.org
 //
 // Permission is hereby granted, free of charge, to any person obtaining
 // a copy of this software and associated documentation files (the
@@ -22,7 +22,6 @@
 //
 
 using System;
-using Glade;
 using Gtk;
 using Mono.Unix;
 using Cairo;
@@ -65,7 +64,7 @@ namespace Mistelix.Dialogs
 
 		static public ResponseType Run ()
 		{
-			response = dialog.RunNoDestroy ();
+			response = (ResponseType) dialog.Run ();
 			return response;
 		}
 
@@ -81,7 +80,7 @@ namespace Mistelix.Dialogs
 	}
 
 	// UI interface to create new Slideshows
-	public class AddSlideDialog : GtkDialog
+	public class AddSlideDialog : BuilderDialog
 	{
 		public enum ColumnsCombo // Column description within the transitions store
 		{	
@@ -100,23 +99,23 @@ namespace Mistelix.Dialogs
 		Project project;
 		const int COL_DISPLAYNAME = 0;
 
-		[Glade.Widget] Gtk.VBox left_vbox;
-		[Glade.Widget ("scrolledwindow_files")] Gtk.ScrolledWindow scrolledwin_files;
-		[Glade.Widget ("vertical_paned")] Gtk.HPaned vpaned;
-		[Glade.Widget ("vpaned_horizontal")] Gtk.VPaned hpaned;
-		[Glade.Widget ("scrolled_images")] Gtk.ScrolledWindow scrolled_images; // View the slide images
-		[Glade.Widget] Gtk.SpinButton duration_spin;
-		[Glade.Widget] Gtk.ComboBox transition_combo;
-		[Glade.Widget] Gtk.HBox ctrls_hbox;
-		[Glade.Widget] Gtk.Button up_button;
-		[Glade.Widget] Gtk.Button down_button;
-		[Glade.Widget] Gtk.Button preview_button;
-		[Glade.Widget] Gtk.Button audio_button;
-		[Glade.Widget] Gtk.VBox vbox_dir;
-		[Glade.Widget] Gtk.ComboBox textposition_combo;
+		[GtkBeans.Builder.Object] Gtk.VBox left_vbox;
+		[GtkBeans.Builder.Object ("scrolledwindow_files")] Gtk.ScrolledWindow scrolledwin_files;
+		[GtkBeans.Builder.Object ("vertical_paned")] Gtk.HPaned vpaned;
+		[GtkBeans.Builder.Object ("vpaned_horizontal")] Gtk.VPaned hpaned;
+		[GtkBeans.Builder.Object ("scrolled_images")] Gtk.ScrolledWindow scrolled_images; // View the slide images
+		[GtkBeans.Builder.Object] Gtk.SpinButton duration_spin;
+		[GtkBeans.Builder.Object] Gtk.ComboBox transition_combo;
+		[GtkBeans.Builder.Object] Gtk.HBox ctrls_hbox;
+		[GtkBeans.Builder.Object] Gtk.Button up_button;
+		[GtkBeans.Builder.Object] Gtk.Button down_button;
+		[GtkBeans.Builder.Object] Gtk.Button preview_button;
+		[GtkBeans.Builder.Object] Gtk.Button audio_button;
+		[GtkBeans.Builder.Object] Gtk.VBox vbox_dir;
+		[GtkBeans.Builder.Object] Gtk.ComboBox textposition_combo;
 
 		// TODO: Since allows editing probably should be renamed to SlideDialog
-		public AddSlideDialog (Project project) : base ("addslide")		
+		public AddSlideDialog (Project project) : base ("AddSlideDialog.ui", "addslide")
 		{
 			this.project = project;
 			LoadWindowPosition ();
@@ -148,11 +147,18 @@ namespace Mistelix.Dialogs
 			transition_store = new ListStore (typeof (string), typeof (string)); // DisplayName, Name
 			LoadTransitionsIntoCombo ();
 			transition_combo.Model = transition_store;
+
+			CellRenderer transition_cell = new CellRendererText ();
+			transition_combo.PackStart (transition_cell, true);
+			transition_combo.SetCellDataFunc (transition_cell, Utils.ComboBoxCellFunc);
 			transition_store.SetSortFunc (0, new Gtk.TreeIterCompareFunc (TransitionSort));
 			transition_store.SetSortColumnId (0, SortType.Ascending);
 
 			textposition_store = new ListStore (typeof (string), typeof (int)); // DisplayName, int
 			textposition_combo.Model = textposition_store;
+			CellRenderer textposition_cell = new CellRendererText ();
+			textposition_combo.PackStart (textposition_cell, true);
+			textposition_combo.SetCellDataFunc (textposition_cell, Utils.ComboBoxCellFunc);
 			LoadTextPositionsIntoCombo ();
 			
 			SetTransisitionToNone ();
@@ -253,13 +259,13 @@ namespace Mistelix.Dialogs
 
 		void OnSaveSlide (object sender, EventArgs args)
 		{
-			Dialog.Respond (ResponseType.Ok);
+			Respond (ResponseType.Ok);
 		}
 
 		// This is a particular case since the Cancel button is not part of the standard dlg button bar
 		void OnCancel (object sender, EventArgs args)
 		{
-			Dialog.Respond (ResponseType.Cancel);
+			Respond (ResponseType.Cancel);
 		}
 
 		void OnTransitionComboChanged (object sender, EventArgs args)
@@ -371,7 +377,7 @@ namespace Mistelix.Dialogs
 		{
 			SlideShow slide_show = GenerateSlideShow ();
 			SlideShowView slide_show_view = new SlideShowView(slide_show);
-			Dialog.Visible = false;
+			Visible = false;
 			FullScreenWindow full_screen = new FullScreenWindow (slide_show_view);
 		}
 
@@ -395,7 +401,7 @@ namespace Mistelix.Dialogs
 		{
 			file_view.Dispose ();
 			image_view.Dispose ();
-			Dialog.Destroy ();
+			Destroy ();
 		}
 
 		void LoadTextPositionsIntoCombo ()
@@ -424,16 +430,16 @@ namespace Mistelix.Dialogs
 			if (x==-1 && y ==-1 && width == -1 && height == -1)
 				return;
 
-			Dialog.Move (x, y);
-			Dialog.Resize (width, height);
+			Move (x, y);
+			Resize (width, height);
 		}
 
 		void SaveWindowPosition ()
 		{
 			int x, y, width, height;
 
-			Dialog.GetPosition (out x, out y);
-			Dialog.GetSize (out width, out height);
+			GetPosition (out x, out y);
+			GetSize (out width, out height);
 
 			Mistelix.Preferences.SetIntValue (Preferences.SlideWindowX, x);
 			Mistelix.Preferences.SetIntValue (Preferences.SlideWindowY, y);
@@ -447,7 +453,7 @@ namespace Mistelix.Dialogs
 			AudioSelectionDialog dialog = new AudioSelectionDialog ();
 			dialog.Filename = audiofile;
 
-			if (dialog.Run () == ResponseType.Ok) {
+			if (dialog.RunModal () == ResponseType.Ok) {
 				audiofile = dialog.Filename;
 			}
 		}
