@@ -248,7 +248,9 @@ namespace Mistelix.Dialogs
 
 			Gtk.TextBuffer buffer_intro = new Gtk.TextBuffer (new Gtk.TextTagTable ());
 			textview_intro.Buffer = buffer_intro;
-			buffer_intro.Text = Catalog.GetString ("Menu themes define how the main DVD menu looks. Here you define the default background image and the type of buttons. For more information visit: http://www.mistelix.org/Themes");		
+			buffer_intro.Text = String.Format (
+				Catalog.GetString ("Menu themes define how the main DVD menu looks. Here you define the default background image and the type of buttons. For more information visit: {0}"),
+				Defines.THEMES_URL);
 		}
 
 		void PrepareTree ()
