@@ -102,7 +102,7 @@ namespace Mistelix
 		public Mistelix (string [] args, params object [] props)
 		: base ("mistelix", Defines.VERSION, Modules.UI,  args, props)
 		{
-			Application.Init ();
+			Gtk.Application.Init ();
 			Logger.Info ("Mistelix " + Defines.VERSION + " starting");
 
 			Catalog.Init ("mistelix", Defines.GNOME_LOCALE_DIR);
@@ -581,7 +581,7 @@ namespace Mistelix
 
 		void OnDocumentation (object sender, EventArgs args)
 		{
-			Process.Start ("http://www.mistelix.org/UserManual");
+			Process.Start (Defines.MANUAL_URL);
 		}
 	
 		void OnCheckDependencies (object sender, EventArgs args)
